@@ -5,7 +5,8 @@ import urlparse
 from lxml import etree
 
 from .lists import SharePointLists
-from .xml import soap_body, namespaces
+from .users import SharePointUsers
+from .xml import soap_body, namespaces, OUT
 
 class SharePointSite(object):
     def __init__(self, url, opener):
@@ -24,8 +25,7 @@ class SharePointSite(object):
         if soapaction:
             request.add_header('Soapaction', soapaction)
         response = self.opener.open(request)
-        r = etree.parse(response).xpath('/soap:Envelope/soap:Body/*', namespaces=namespaces)[0]
-        return r
+        return etree.parse(response).xpath('/soap:Envelope/soap:Body/*', namespaces=namespaces)[0]
 
     @property
     def lists(self):
@@ -33,10 +33,19 @@ class SharePointSite(object):
             self._lists = SharePointLists(self.opener)
         return self._lists
 
-def basic_auth_opener(url, username, password):
-    password_manager = urllib2.HTTPPasswordMgrWithDefaultRealm()
-    password_manager.add_password(None, url, username, password)
-    auth_handler = urllib2.HTTPBasicAuthHandler(password_manager)
-    opener = urllib2.build_opener(auth_handler)
-    return opener
+    @property
+    def users(self):
+        if not hasattr(self, '_users'):
+            self._users = SharePointUsers(self.opener)
+        return self._users
 
+    def as_xml(self, include_lists=False, include_users=False, **kwargs):
+        xml = OUT.site(url=self.opener.base_url)
+        if include_lists or kwargs.get('list_names'):
+            xml.append(self.lists.as_xml(**kwargs))
+        if include_users:
+            if 'user_ids' not in kwargs:
+                kwargs['user_ids'] = set(xml.xpath('.//sharepoint:user/@id', namespaces=namespaces))
+            xml.append(self.users.as_xml(**kwargs))
+        return xml
+            
